@@ -26,7 +26,7 @@ from teedoc_plugin_markdown_parser.parse_metadata import Meta_Parser
 from teedoc_plugin_markdown_parser.renderer import create_markdown_parser
 
 
-__version__ = "1.1.1"
+__version__ = "1.1.3"
 
 
 class Plugin(Plugin_Base):
@@ -126,22 +126,21 @@ class Plugin(Plugin_Base):
                         brief = html[:500].strip()
                     parent_url = os.path.dirname(file.replace(self.doc_src_path, ""))
                     brief = self._update_relative_brief_links(brief, parent_url)
-                    if "title" in metadata:
-                        title = metadata["title"]
-                    else:
-                        title = ""
-                    if "keywords" in metadata and not metadata["keywords"].strip() == "":
-                        keywords = metadata["keywords"].split(",")
-                    else:
-                        keywords = []
-                    if "tags" in metadata and not metadata["tags"].strip() == "":
-                        tags = metadata["tags"].split(",")
-                    else:
-                        tags = []
-                    if "desc" in metadata:
-                        desc = metadata["desc"]
-                    else:
-                        desc = ""
+                    title = metadata.get("title", "")
+                    desc = metadata.get("desc", "")
+                    author = metadata.get("author", "")
+                    keywords = []
+                    if "keywords" in metadata:
+                        if type(metadata["keywords"]) == list:
+                            keywords = metadata["keywords"]
+                        else:
+                            keywords = metadata["keywords"].split(",")
+                    tags = []
+                    if "tags" in metadata:
+                        if type(metadata["tags"]) == list:
+                            tags = metadata["tags"]
+                        else:
+                            tags = metadata["tags"].split(",")
                     if "cover" in metadata:
                         cover = metadata["cover"]
                         cover = self._rel_to_abs_url(cover, parent_url)
@@ -149,27 +148,17 @@ class Plugin(Plugin_Base):
                     else:
                         cover = ""
                     html_str = '<span id="blog_start"></span>' + html
-                    # date default last edit time
-                    ts = int(os.stat(file).st_mtime)
-                    date_file_edit = time.strftime("%Y-%m-%d", time.localtime(ts))
-                    if "date" in metadata:
-                        date = metadata["date"].strip().lower()
-                        # set date to false to disable date display
-                        if date and (date == "false" or date == "none"):
-                            date = False
+                    date = None
+                    ts = None
+                    if "date" in metadata and type(metadata["date"]) == datetime:
+                        date = metadata["date"]
+                        if type(date) == datetime.date:
+                            ts = int(time.mktime(date.timetuple()))
                         else:
-                            GMT_FORMAT = '%Y-%m-%d'
-                            try:
-                                date_obj = datetime.strptime(date, GMT_FORMAT)
-                                ts = int(date_obj.timestamp())
-                            except Exception as e:
-                                date = date_file_edit
+                            ts = int(date.timestamp())
                     else:
-                        date = date_file_edit
-                    if "author" in metadata:
-                        author = metadata["author"]
-                    else:
-                        author = ""
+                        ts = int(os.stat(file).st_mtime)
+                        date = datetime.fromtimestamp(ts)
                     result["htmls"][file] = {
                         "title": title,
                         "desc": desc,
